@@ -30,13 +30,15 @@
 
 #define MAXLINE 1024
 
+static MpSerializer *result_serializer;
+
 static void
 solve(const char *equation)
 {
     int ret;
     MPEquationOptions options;
     MPNumber z;
-    char result_str[MAXLINE];
+    gchar *result_str = NULL;
     
     memset(&options, 0, sizeof(options));
     options.base = 10;
@@ -50,9 +52,10 @@ solve(const char *equation)
     else if (ret)        
         fprintf(stderr, "Error %d\n", ret);
     else {
-        mp_serializer_to_specific_string(&z, 10, 9, true, true, result_str, MAXLINE);
+        result_str = mp_serializer_to_string(result_serializer, &z);
         printf("%s\n", result_str);
     }
+    g_free(result_str);
 }
 
 
@@ -82,7 +85,9 @@ main(int argc, char **argv)
     srand48((long) time((time_t *) 0));
 
     g_type_init ();
-    setlocale(LC_NUMERIC, "");
+    setlocale(LC_ALL, "");
+
+    result_serializer = mp_serializer_new(MP_DISPLAY_FORMAT_AUTOMATIC, 10, 9);
 
     equation = (char *) malloc(MAXLINE * sizeof(char));
     while (1) {
