@@ -512,6 +512,7 @@ char_val(char **c, int base)
 {
     int i, j, value, offset;
     const char *digits[][10] = {{"٠", "١", "٢", "٣", "٤", "٥", "٦", "٧", "٨", "٩"},
+                                {"〇", "〡", "〢", "〣", "〤", "〥", "〦", "〧", "〨", "〩"},
                                 {"۰", "۱", "۲", "۳", "۴", "۵", "۶", "۷", "۸", "۹"},
                                 {"߀", "߁", "߂", "߃", "߄", "߅", "߆", "߇", "߈", "߉"},
                                 {"०", "१", "२", "३", "४", "५", "६", "७", "८", "९"},
@@ -628,18 +629,6 @@ mp_set_from_string(const char *str, int default_base, MPNumber *z)
     const char *fractions[]     = {"½", "⅓", "⅔", "¼", "¾", "⅕", "⅖", "⅗", "⅘", "⅙", "⅚", "⅛", "⅜", "⅝", "⅞", NULL};
     int numerators[]            = { 1,   1,   2,   1,   3,   1,   2,   3,   4,   1,   5,   1,   3,   5,   7};
     int denominators[]          = { 2,   3,   3,   4,   4,   5,   5,   5,   5,   6,   6,   8,   8,   8,   8};
-    static const char *tsep = NULL;
-    static const char *radix = NULL;
-
-    if (radix == NULL) {
-        radix = nl_langinfo(RADIXCHAR);
-        radix = *radix ? g_locale_to_utf8(radix, -1, NULL, NULL, NULL) : g_strdup(".");
-    }
-
-    if (tsep == NULL) {
-        tsep = nl_langinfo(THOUSEP);
-        tsep = *tsep ? g_locale_to_utf8(tsep, -1, NULL, NULL, NULL) : tsep;
-    }
 
     if (strstr(str, "°"))
         return set_from_sexagesimal(str, strlen(str), z);
@@ -678,20 +667,11 @@ mp_set_from_string(const char *str, int default_base, MPNumber *z)
 
     /* Convert integer part */
     mp_set_from_integer(0, z);
-    while (1) {
-        i = char_val((char **)&c, base);
-        if (i < 0)
-            break;
-
+    while ((i = char_val((char **)&c, base)) >= 0) {
         if (i > base)
             return true;
         mp_multiply_integer(z, base, z);
         mp_add_integer(z, i, z);
-
-        // Must be after the first digit, as locales with tsep = ' ' becomes
-        // buggy otherwise.
-        if (*tsep && strncmp(c, tsep, strlen(tsep)) == 0)
-            c += strlen(tsep);
     }
 
     /* Look for fraction characters, e.g. ⅚ */
@@ -707,11 +687,7 @@ mp_set_from_string(const char *str, int default_base, MPNumber *z)
         mp_add(z, &fraction, z);
     }
 
-    /* Accept both the user's local radix point (usually '.' or ','), and the
-     * english '.', since at least europeans frequently use '.' despite ','
-     * being the correct one for their locale.
-     */
-    if (*c == '.' || strncmp(c, radix, strlen(radix)) == 0) {
+    if (*c == '.') {
         has_fraction = TRUE;
         c++;
     }
